# Contributing

This package was developped and maintained by Advestis, initially for an internal use, and was later shared to the public as it could benefit many.

However, since Advestis is not a software developpement company but a contract research organization, its dedicated development team is not large enough to
handle an active community efficiently. For this reason, the following contributing guidelines are to be followed.

## Pull Requests

The community's pull requests will not be treated. We would not have the time to review them. They will be closed with the suggestion to open them as Issues.

## Issues

### Bug issues

Issues reporting problems will of course be treated as quickly as possible by our team.

### Feature requests

The community can open issues to request new functionnalities. We do not guarantee any quick answer however.
